﻿# -*- coding: utf-8 -*-
###########################################################################
## All global variables in here are data either saved or loaded for/from a record file
###########################################################################

MaxArrayDataLen=8640 #(1 value/10sec for 24h), 6*24*60

arrData=[[""]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [""]*MaxArrayDataLen, [0]*MaxArrayDataLen]

#field 1:
    #0 Time (String)
    #1 X movement
    #2 Y movement
    #3 Z movement
    #4 Sum of X+Y+Z Derivation
    #5 Sum of X+Y+Z Derivation with noise reduction
    #6 SleepFilter (Derivation multiplied with filter window)
#field 2:
    # samples

Index=-1
LastIndex=-1 #maximum from Index and AlarmTimeWindowEnd index



arrStatData=[[0]*4,  [0]*4,  [0]*4]
#field 1:
    # Awake time
    # Light sleep
    # Deep Sleep
#field 2:
    # Accumulated time/phase,    Amount of times/phase,    Max time/phase,    Time percent




StartTime_tuple=-1
StartTime_seconds=-1

EndTime_tuple=-1
EndTime_seconds=-1

AlarmTime_tuple=-1
AlarmTime_seconds=-1

AlarmIsSet=False

AlarmTimeWindowStart_tuple=-1
AlarmTimeWindowStart_seconds=-1

AlarmTimeWindowEnd_tuple=-1
AlarmTimeWindowEnd_seconds=-1

AlarmTimeWindow_minutes=-1

status=""
statusID=-1

Note=""
User=""
SWversion=""

Sampling_interval=-1
Sample_smoothing=-1
Value_smoothing=-1

Trigger=-1


Use_Lucid_Dream_Song = False
Lucid_Dream_Song_Start_tuple = -1
Lucid_Dream_Song = ""
Lucid_Dream_Song_Delay = -1
Lucid_Dream_Song_Duration = -1
Lucid_Dream_Song_Volume = -1

Use_WakeUp_Song = False
WakeUp_Song_Start_tuple = -1
WakeUp_Song = ""
WakeUp_Song_Duration = -1
WakeUp_Song_Volume= -1
